@@ -15,14 +15,14 @@ from .ogc import WebFeatureService
 from .geopedia import GeopediaFeatureIterator, GeopediaSession
 
 from .geometry import BBox, Geometry, BBoxCollection
-from .constants import CustomUrlParam, CRS, MimeType, SHConstants, AwsConstants, ServiceType, \
+from .constants import CustomUrlParam, CRS, MimeType, SHConstants, AwsConstants, ServiceType, ServiceUrl, \
     HistogramType
 from .data_collections import DataCollection, DataSource
 
 from .config import SHConfig
 
-from .download import DownloadRequest, get_json, get_xml, DownloadClient, AwsDownloadClient, \
-    SentinelHubDownloadClient, SentinelHubStatisticalDownloadClient
+from .download import DownloadRequest, DownloadClient, AwsDownloadClient, SentinelHubDownloadClient, \
+    SentinelHubStatisticalDownloadClient
 
 from .exceptions import DownloadFailedException, AwsDownloadFailedException
 
@@ -32,12 +32,10 @@ from .io_utils import read_data, write_data
 from .os_utils import get_content_list, get_folder_list, get_file_list, make_folder, create_parent_folder, rename, size
 from .geo_utils import bbox_to_dimensions, bbox_to_resolution, get_image_dimension, to_utm_bbox, get_utm_bbox,\
     wgs84_to_utm, to_wgs84, utm_to_pixel, pixel_to_utm, wgs84_to_pixel, get_utm_crs, transform_point
-from .time_utils import next_date, prev_date, get_current_date
-
-from .testing_utils import TestSentinelHub, TestCaseContainer
 
 from .sentinelhub_session import SentinelHubSession
-from .sentinelhub_batch import SentinelHubBatch
+from .sentinelhub_batch import SentinelHubBatch, BatchRequest, BatchCollection, monitor_batch_job, BatchRequestStatus, \
+    BatchTileStatus, BatchUserAction
 from .sentinelhub_request import SentinelHubRequest
 from .sentinelhub_byoc import SentinelHubBYOC, ByocCollection, ByocCollectionAdditionalData, ByocTile
 from .sentinelhub_catalog import SentinelHubCatalog
