@@ -18,6 +18,8 @@ class SHConfig:
         - `sh_client_secret`: User's OAuth client secret for Sentinel Hub service
         - `sh_base_url`: There exist multiple deployed instances of Sentinel Hub service, this parameter defines the
           location of a specific service instance.
+        - `sh_auth_base_url`: Base url for Sentinel Hub Authentication service. Authentication is typically sent to the
+          main service deployment even if `sh_base_url` points to another deployment.
         - `geopedia_wms_url`: Base url for Geopedia WMS services.
         - `geopedia_rest_url`: Base url for Geopedia REST services.
         - `aws_access_key_id`: Access key for AWS Requester Pays buckets.
@@ -29,7 +31,8 @@ class SHConfig:
         - `max_wfs_records_per_query`: Maximum number of records returned for each WFS query.
         - `max_opensearch_records_per_query`: Maximum number of records returned for each Opensearch query.
         - `max_download_attempts`: Maximum number of download attempts from a single URL until an error will be raised.
-        - `download_sleep_time`: Number of seconds between the failed download attempt and the next attempt.
+        - `download_sleep_time`: Number of seconds to sleep between the first failed attempt and the next. Every next
+          attempt this number exponentially increases with factor `3`.
         - `download_timeout_seconds`: Maximum number of seconds before download attempt is canceled.
         - `number_of_download_processes`: Number of download processes, used to calculate rate-limit sleep time.
 
@@ -47,6 +50,7 @@ class SHConfig:
             'sh_client_id': '',
             'sh_client_secret': '',
             'sh_base_url': 'https://services.sentinel-hub.com',
+            'sh_auth_base_url': 'https://services.sentinel-hub.com',
             'geopedia_wms_url': 'https://service.geopedia.world',
             'geopedia_rest_url': 'https://www.geopedia.world/rest',
             'aws_access_key_id': '',
@@ -62,6 +66,13 @@ class SHConfig:
             'download_timeout_seconds': 120.0,
             'number_of_download_processes': 1
         }
+        CREDENTIALS = {
+            'instance_id',
+            'sh_client_id',
+            'sh_client_secret',
+            'aws_access_key_id',
+            'aws_secret_access_key'
+        }
 
         def __init__(self):
             self.instance_id = ''
@@ -70,16 +81,16 @@ class SHConfig:
         def _parse_configuration(self, config):
             """ Checks if configuration file contains all keys and parses values
             """
-            for param in self.CONFIG_PARAMS:
+            for param, default_value in self.CONFIG_PARAMS.items():
                 if param not in config:
-                    raise ValueError("Configuration file does not contain '%s' parameter." % param)
+                    config[param] = default_value
 
             for param, default_param in self.CONFIG_PARAMS.items():
                 param_type = type(default_param)
                 if (param_type is float) and isinstance(config[param], numbers.Number):
                     continue
                 if not isinstance(config[param], param_type):
-                    raise ValueError("Value of parameter '{}' must be of type {}".format(param, param_type.__name__))
+                    raise ValueError(f"Value of parameter '{param}' must be of type {param_type.__name__}")
 
             if config['max_wfs_records_per_query'] > 100:
                 raise ValueError("Value of config parameter 'max_wfs_records_per_query' must be at most 100")
@@ -126,9 +137,10 @@ class SHConfig:
             :return: A dictionary
             :rtype: dict
             """
-            config = {prop: getattr(self, prop) for prop in self.CONFIG_PARAMS}
-            if config['instance_id'] is None:
-                config['instance_id'] = ''
+            config = {item: getattr(self, item) for item in self.CONFIG_PARAMS}
+            for item, default_value in self.CONFIG_PARAMS.items():
+                if config[item] is None:
+                    config[item] = default_value
             return config
 
         def save_configuration(self):
@@ -143,7 +155,15 @@ class SHConfig:
 
     _instance = None
 
-    def __init__(self):
+    def __init__(self, hide_credentials=False):
+        """
+        :param hide_credentials: If `True` then methods that provide the entire content of the config object will mask
+            out all credentials. But credentials could still be accessed directly from config object attributes. The
+            default is `False`.
+        :type hide_credentials: bool
+        """
+        self._hide_credentials = hide_credentials
+
         if not SHConfig._instance:
             SHConfig._instance = self._SHConfig()
 
@@ -162,14 +182,16 @@ class SHConfig:
         return sorted(list(dir(super())) + list(self._instance.CONFIG_PARAMS))
 
     def __str__(self):
-        """ Content of SHConfig in json schema
+        """ Content of SHConfig in json schema. If `hide_credentials` is set to `True` then credentials will be
+        masked.
         """
         return json.dumps(self.get_config_dict(), indent=2)
 
     def __repr__(self):
-        """ Representation of SHConfig parameters
+        """ Representation of SHConfig parameters. If `hide_credentials` is set to `True` then credentials will be
+        masked.
         """
-        repr_list = ['{}('.format(self.__class__.__name__)]
+        repr_list = [f'{self.__class__.__name__}(']
 
         for key, value in self.get_config_dict().items():
             repr_list.append('%s=%r,' % (key, value))
@@ -210,7 +232,7 @@ class SHConfig:
                 self._reset_param(param)
         else:
             raise ValueError('Parameters must be specified in form of a list of strings or as a single string, instead '
-                             'got {}'.format(params))
+                             f'got {params}')
 
     def _reset_param(self, param):
         """ Resets a single parameter
@@ -219,7 +241,7 @@ class SHConfig:
         :type param: str
         """
         if param not in self._instance.CONFIG_PARAMS:
-            raise ValueError("Cannot reset unknown parameter '{}'".format(param))
+            raise ValueError(f"Cannot reset unknown parameter '{param}'")
         setattr(self, param, self._instance.CONFIG_PARAMS[param])
 
     def get_params(self):
@@ -231,12 +253,18 @@ class SHConfig:
         return list(self._instance.CONFIG_PARAMS)
 
     def get_config_dict(self):
-        """ Get a dictionary representation of `SHConfig` class
+        """ Get a dictionary representation of `SHConfig` class. If `hide_credentials` is set to `True` then
+        credentials will be masked.
 
         :return: A dictionary with configuration parameters
         :rtype: dict
         """
-        return {prop: getattr(self, prop) for prop in self._instance.CONFIG_PARAMS}
+        config_params = {param: getattr(self, param) for param in self._instance.CONFIG_PARAMS}
+
+        if self._hide_credentials:
+            config_params = {param: self._mask_credentials(param, value) for param, value in config_params.items()}
+
+        return config_params
 
     def get_config_location(self):
         """ Returns location of configuration file on disk
@@ -260,7 +288,7 @@ class SHConfig:
         :return: An URL endpoint
         :rtype: str
         """
-        return '{}/oauth/token'.format(self.sh_base_url)
+        return f'{self.sh_auth_base_url}/oauth/token'
 
     def get_sh_process_api_url(self):
         """  Provides URL for Sentinel Hub Process API endpoint
@@ -268,7 +296,7 @@ class SHConfig:
         :return: An URL endpoint
         :rtype: str
         """
-        return '{}/api/v1/process'.format(self.sh_base_url)
+        return f'{self.sh_base_url}/api/v1/process'
 
     def get_sh_ogc_url(self):
         """ Provides URL for Sentinel Hub OGC endpoint
@@ -277,7 +305,7 @@ class SHConfig:
         :rtype: str
         """
         ogc_endpoint = 'v1' if self.has_eocloud_url() else 'ogc'
-        return '{}/{}'.format(self.sh_base_url, ogc_endpoint)
+        return f'{self.sh_base_url}/{ogc_endpoint}'
 
     def get_sh_rate_limit_url(self):
         """ Provides URL for Sentinel Hub rate limiting endpoint
@@ -285,7 +313,7 @@ class SHConfig:
         :return: An URL endpoint
         :rtype: str
         """
-        return '{}/aux/ratelimit'.format(self.sh_base_url)
+        return f'{self.sh_auth_base_url}/aux/ratelimit'
 
     def raise_for_missing_instance_id(self):
         """ In case Sentinel Hub instance ID is missing it raises an informative error
@@ -296,3 +324,14 @@ class SHConfig:
             raise ValueError('Sentinel Hub instance ID is missing. '
                              'Either provide it with SHConfig object or save it into config.json configuration file. '
                              'Check http://sentinelhub-py.readthedocs.io/en/latest/configure.html for more info.')
+
+    def _mask_credentials(self, param, value):
+        """ In case a credentials parameter is given it will mask its value
+        """
+        if not (param in self._instance.CREDENTIALS and value):
+            return value
+        if not isinstance(value, str):
+            raise ValueError(f"Parameter '{param}' should be a string but {value} found")
+
+        hide_size = min(max(len(value) - 4, 10), len(value))
+        return '*' * hide_size + value[hide_size:]
