@@ -1,20 +1,21 @@
 """
 Module implementing the main download client class
 """
-import concurrent.futures
 import logging
 import warnings
 import os
 import sys
+from concurrent.futures import ThreadPoolExecutor, as_completed
 
 import requests
+from tqdm.auto import tqdm
 
 from ..config import SHConfig
 from ..constants import RequestType, MimeType
 from ..decoding import decode_data as decode_data_function
-from ..exceptions import DownloadFailedException, SHRuntimeWarning, SHDeprecationWarning
+from ..exceptions import DownloadFailedException, SHRuntimeWarning, HashedNameCollisionException
 from ..io_utils import read_data, write_data
-from .handlers import fail_user_errors, retry_temporal_errors
+from .handlers import fail_user_errors, retry_temporary_errors
 from .request import DownloadRequest
 
 
@@ -48,7 +49,7 @@ class DownloadClient:
 
         self.config = config or SHConfig()
 
-    def download(self, download_requests, max_threads=None, decode_data=True):
+    def download(self, download_requests, max_threads=None, decode_data=True, show_progress=False):
         """ Download one or multiple requests, provided as a request list.
 
         :param download_requests: A list of requests or a single request to be executed.
@@ -58,6 +59,8 @@ class DownloadClient:
         :type max_threads: int or None
         :param decode_data: If `True` it will decode data otherwise it will return it in binary format.
         :type decode_data: bool
+        :param show_progress: Whether a progress bar should be displayed while downloading
+        :type show_progress: bool
         :return: A list of results or a single result, depending on input parameter `download_requests`
         :rtype: list(object) or object
         """
@@ -65,27 +68,40 @@ class DownloadClient:
         if is_single_request:
             download_requests = [download_requests]
 
-        with concurrent.futures.ThreadPoolExecutor(max_workers=max_threads) as executor:
+        with ThreadPoolExecutor(max_workers=max_threads) as executor:
             download_list = [
                 executor.submit(self._single_download, request, decode_data) for request in download_requests
             ]
+            future_order = {future: i for i, future in enumerate(download_list)}
 
-        data_list = []
-        for future in download_list:
-            try:
-                data_list.append(future.result())
-            except DownloadFailedException as download_exception:
-                if self.raise_download_errors:
-                    traceback = sys.exc_info()[2]
-                    raise download_exception.with_traceback(traceback)
-
-                warnings.warn(str(download_exception), category=SHRuntimeWarning)
-                data_list.append(None)
+        data_list = [None] * len(download_list)
+        # Consider using tqdm.contrib.concurrent.thread_map in the future
+        if show_progress:
+            with tqdm(total=len(download_list)) as pbar:
+                for future in as_completed(download_list):
+                    data_list[future_order[future]] = self._process_download_future(future)
+                    pbar.update(1)
+        else:
+            for future in as_completed(download_list):
+                data_list[future_order[future]] = self._process_download_future(future)
 
         if is_single_request:
             return data_list[0]
         return data_list
 
+    def _process_download_future(self, future):
+        """ Unpacks the future and correctly handles exceptions
+        """
+        try:
+            return future.result()
+        except DownloadFailedException as download_exception:
+            if self.raise_download_errors:
+                traceback = sys.exc_info()[2]
+                raise download_exception.with_traceback(traceback)
+
+            warnings.warn(str(download_exception), category=SHRuntimeWarning)
+            return None
+
     def _single_download(self, request, decode_data):
         """ Method for downloading a single request
         """
@@ -95,6 +111,8 @@ class DownloadClient:
 
         if not self._is_download_required(request, response_path):
             if request.return_data:
+                LOGGER.debug('Reading locally stored data from %s instead of downloading', response_path)
+                self._check_cached_request_is_matching(request, request_path)
                 return read_data(response_path, data_format=request.data_type if decode_data else MimeType.RAW)
             return None
 
@@ -115,11 +133,14 @@ class DownloadClient:
             return response_content
         return None
 
-    @retry_temporal_errors
+    @retry_temporary_errors
     @fail_user_errors
     def _execute_download(self, request):
         """ A default way of executing a single download request
         """
+        LOGGER.debug('Sending %s request to %s. Hash of sent request is %s',
+                     request.request_type.value, request.url, request.get_hashed_name())
+
         response = requests.request(
             request.request_type.value,
             url=request.url,
@@ -129,7 +150,7 @@ class DownloadClient:
         )
 
         response.raise_for_status()
-        LOGGER.debug('Successful download from %s', request.url)
+        LOGGER.debug('Successful %s request to %s', request.request_type.value, request.url)
 
         return response.content
 
@@ -139,6 +160,22 @@ class DownloadClient:
         return (request.save_response or request.return_data) and \
                (self.redownload or response_path is None or not os.path.exists(response_path))
 
+    @staticmethod
+    def _check_cached_request_is_matching(request, request_path):
+        """ Ensures that the cached request matches the current one. Serves as protection against hash collisions
+        """
+        cached_request_info = read_data(request_path, MimeType.JSON)
+        current_request_info = request.get_request_params(include_metadata=False)
+        # Timestamps are allowed to differ
+        del cached_request_info['timestamp']
+        del cached_request_info['headers']
+
+        if cached_request_info != current_request_info:
+            raise HashedNameCollisionException(
+                f'Request has hashed name {request.get_hashed_name()}, which matches request saved at {request_path}, '
+                f'but the requests are different. Possible hash collision'
+            )
+
     def get_json(self, url, post_values=None, headers=None, request_type=None, **kwargs):
         """ Download request as JSON data type
 
@@ -182,50 +219,3 @@ class DownloadClient:
         """
         request = DownloadRequest(url=url, data_type=MimeType.XML, **kwargs)
         return self._single_download(request, decode_data=True)
-
-
-def get_json(url, post_values=None, headers=None, request_type=None, download_client_class=DownloadClient, **kwargs):
-    """ Download request as JSON data type
-
-    :param url: An URL from where the data will be downloaded
-    :type url: str
-    :param post_values: A dictionary of parameters for a POST request
-    :type post_values: dict or None
-    :param headers: A dictionary of additional request headers
-    :type headers: dict
-    :param request_type: A type of HTTP request to make. If not specified, then it will be a GET request if
-        `post_values=None` and a POST request otherwise
-    :type request_type: RequestType or None
-    :param download_client_class: A class that implements a download client
-    :type download_client_class: object
-    :param kwargs: Parameters that are passed to a DownloadRequest class
-    :return: JSON data parsed into Python objects
-    :rtype: object or None
-    """
-    warnings.warn('Function get_json is deprecated and will soon be removed, please use DownloadClient.get_json '
-                  'instead', category=SHDeprecationWarning)
-
-    return download_client_class().get_json(
-        url=url,
-        post_values=post_values,
-        headers=headers,
-        request_type=request_type,
-        **kwargs
-    )
-
-
-def get_xml(url, download_client_class=DownloadClient):
-    """ Download request as XML data type
-
-    :param url: url to Sentinel Hub's services or other sources from where the data is downloaded
-    :type url: str
-    :return: request response as XML instance
-    :rtype: XML instance or None
-    :param download_client_class: A class that implements a download client
-    :type download_client_class: object
-    :raises: RunTimeError
-    """
-    warnings.warn('Function get_xml is deprecated and will soon be removed, please use DownloadClient.get_xml '
-                  'instead', category=SHDeprecationWarning)
-
-    return download_client_class().get_xml(url)
