@@ -21,8 +21,8 @@ def fail_user_errors(download_func):
         try:
             return download_func(self, request)
         except requests.HTTPError as exception:
-            if exception.response.status_code < requests.status_codes.codes.INTERNAL_SERVER_ERROR and \
-                exception.response.status_code != requests.status_codes.codes.TOO_MANY_REQUESTS:
+            if (exception.response.status_code < requests.status_codes.codes.INTERNAL_SERVER_ERROR and
+                    exception.response.status_code != requests.status_codes.codes.TOO_MANY_REQUESTS):
 
                 raise DownloadFailedException(_create_download_failed_message(exception, request.url)) from exception
             raise exception from exception
@@ -30,7 +30,7 @@ def fail_user_errors(download_func):
     return new_download_func
 
 
-def retry_temporal_errors(download_func):
+def retry_temporary_errors(download_func):
     """ Decorator function for handling server and connection errors
     """
     backoff_coefficient = 3
@@ -44,14 +44,14 @@ def retry_temporal_errors(download_func):
                 return download_func(self, request)
             except requests.RequestException as exception:
 
-                if not (_is_temporal_problem(exception) or
+                if not (_is_temporary_problem(exception) or
                         (isinstance(exception, requests.HTTPError) and
                          exception.response.status_code >= requests.status_codes.codes.INTERNAL_SERVER_ERROR)):
                     raise exception from exception
 
                 if attempt_num == download_attempts - 1:
-                    raise DownloadFailedException(_create_download_failed_message(exception, request.url)) \
-                        from exception
+                    message = _create_download_failed_message(exception, request.url)
+                    raise DownloadFailedException(message) from exception
 
                 LOGGER.debug('Download attempt failed: %s\n%d attempts left, will retry in %ds', exception,
                              download_attempts - attempt_num - 1, sleep_time)
@@ -72,19 +72,19 @@ def fail_missing_file(download_func):
             return download_func(self, request)
         except requests.HTTPError as exception:
             if exception.response.status_code == requests.status_codes.codes.NOT_FOUND:
-                raise DownloadFailedException('File in location %s is missing' % request.url) from exception
+                raise DownloadFailedException(f'File in location {request.url} is missing') from exception
 
             raise exception from exception
 
     return new_download_func
 
 
-def _is_temporal_problem(exception):
-    """ Checks if the obtained exception is temporal and if download attempt should be repeated
+def _is_temporary_problem(exception):
+    """ Checks if the obtained exception is temporary and if download attempt should be repeated
 
     :param exception: Exception raised during download
     :type exception: Exception
-    :return: `True` if exception is temporal and `False` otherwise
+    :return: `True` if exception is temporary and `False` otherwise
     :rtype: bool
     """
     return isinstance(exception, (requests.ConnectionError,
@@ -102,9 +102,9 @@ def _create_download_failed_message(exception, url):
     :return: Error message
     :rtype: str
     """
-    message = 'Failed to download from:\n{}\nwith {}:\n{}'.format(url, exception.__class__.__name__, exception)
+    message = f'Failed to download from:\n{url}\nwith {exception.__class__.__name__}:\n{exception}'
 
-    if _is_temporal_problem(exception):
+    if _is_temporary_problem(exception):
         if isinstance(exception, requests.ConnectionError):
             message += '\nPlease check your internet connection and try again.'
         else:
@@ -112,6 +112,6 @@ def _create_download_failed_message(exception, url):
                        'your request. Please try again.'
     elif isinstance(exception, requests.HTTPError):
         server_message = decode_sentinelhub_err_msg(exception.response)
-        message += '\nServer response: "{}"'.format(server_message)
+        message += f'\nServer response: "{server_message}"'
 
     return message
