@@ -35,6 +35,11 @@ class MissingDataInRequestException(BaseSentinelHubException):
     """
 
 
+class HashedNameCollisionException(BaseSentinelHubException):
+    """This exception is raised when two different requests are assigned the same hashed name.
+    """
+
+
 class SHDeprecationWarning(DeprecationWarning):
     """ A custom deprecation warning for sentinelhub-py package
     """
@@ -46,10 +51,16 @@ class SHUserWarning(UserWarning):
 
 
 class SHRuntimeWarning(RuntimeWarning):
-    """ A custom runtime warning for sentinelhub-py package, it should be
+    """ A custom runtime warning for sentinelhub-py package
+    """
+
+
+class SHRateLimitWarning(SHRuntimeWarning):
+    """ A custom runtime warning in case user hit the rate limit for downloads
     """
 
 
 warnings.simplefilter('default', SHDeprecationWarning)
 warnings.simplefilter('default', SHUserWarning)
 warnings.simplefilter('always', SHRuntimeWarning)
+warnings.simplefilter('always', SHRateLimitWarning)
