@@ -22,12 +22,6 @@ class BaseGeometry(ABC):
         """
         self._crs = CRS(crs)
 
-    def _repr_svg_(self):
-        """ Using shapely's svg geometry visualization for Jupyter notebooks
-        """
-        # pylint: disable=protected-access
-        return self.geometry._repr_svg_()
-
     @property
     def crs(self):
         """ Returns the coordinate reference system (CRS)
@@ -51,18 +45,24 @@ class BaseGeometry(ABC):
         :return: A dictionary in GeoJSON format
         :rtype: dict
         """
-        return {
-            **self._crs_to_geojson(),
-            **shapely.geometry.mapping(self.geometry)
-        }
+        return self.get_geojson(with_crs=True)
 
-    def get_geojson(self):
+    def get_geojson(self, with_crs=True):
         """ Returns representation in a GeoJSON format. Use json.dump for writing it to file.
 
+        :param with_crs: A flag indicating if GeoJSON dictionary should contain CRS part
+        :type with_crs: bool
         :return: A dictionary in GeoJSON format
         :rtype: dict
         """
-        return self.geojson
+        geometry_geojson = shapely.geometry.mapping(self.geometry)
+
+        if with_crs:
+            return {
+                **self._crs_to_geojson(),
+                **geometry_geojson
+            }
+        return geometry_geojson
 
     def _crs_to_geojson(self):
         """ Helper method which generates part of GeoJSON format related to CRS
@@ -411,7 +411,7 @@ class Geometry(BaseGeometry):
     def __repr__(self):
         """ Method for class representation
         """
-        return f'{self.__class__.__name__}({self.wkt}, crs={self.crs})'
+        return f'{self.__class__.__name__}({self.wkt}, crs={repr(self.crs)})'
 
     def __eq__(self, other):
         """ Method for comparing two Geometry classes
