@@ -3,15 +3,13 @@ Module for communication with http://opensearch.sentinel-hub.com/resto/api
 
 For more search parameters check: http://opensearch.sentinel-hub.com/resto/api/collections/Sentinel2/describe.xml
 """
-
 import logging
-import datetime
 from urllib.parse import urlencode
 
 from .constants import CRS
 from .config import SHConfig
 from .download import DownloadClient
-from .time_utils import parse_time_interval
+from .time_utils import parse_time_interval, parse_time, serialize_time
 
 
 LOGGER = logging.getLogger(__name__)
@@ -48,8 +46,8 @@ def get_tile_info(tile, time, aws_index=None, all_tiles=False):
 
     :param tile: tile name (e.g. ``'T10UEV'``)
     :type tile: str
-    :param time: A single date or a time interval, times have to be in ISO 8601 string
-    :type time: str or (str, str)
+    :param time: A single date or a time interval
+    :type time: str or (str, str) or datetime.date or (datetime.date, datetime.date)
     :param aws_index: index of tile on AWS
     :type aws_index: int or None
     :param all_tiles: If `True` it will return list of all tiles otherwise only the first one
@@ -67,13 +65,18 @@ def get_tile_info(tile, time, aws_index=None, all_tiles=False):
         if this_tile == tile.lstrip('T0') and (aws_index is None or aws_index == this_aws_index):
             candidates.append(tile_info)
 
+        if candidates and aws_index is not None:
+            break
+        if len(candidates) >= 2 and not all_tiles:
+            break
+
     if not candidates:
         raise TileMissingException
-
-    if len(candidates) > 1:
-        LOGGER.info('Obtained %d results for tile=%s, time=%s. Returning the first one', len(candidates), tile, time)
     if all_tiles:
         return candidates
+
+    if len(candidates) > 1:
+        LOGGER.info('Obtained more than one result for tile=%s, time=%s. Returning the first one', tile, time)
     return candidates[0]
 
 
@@ -109,9 +112,7 @@ def get_area_dates(bbox, date_interval, maxcc=None):
     """
 
     area_info = get_area_info(bbox, date_interval, maxcc=maxcc)
-    return sorted({datetime.datetime.strptime(tile_info['properties']['startDate'].strip('Z'),
-                                              '%Y-%m-%dT%H:%M:%S')
-                   for tile_info in area_info})
+    return sorted({parse_time(tile_info['properties']['startDate']) for tile_info in area_info})
 
 
 def reduce_by_maxcc(result_list, maxcc):
@@ -137,9 +138,9 @@ def search_iter(tile_id=None, bbox=None, start_date=None, end_date=None, absolut
     :type tile_id: str
     :param bbox: bounding box of requested area
     :type bbox: geometry.BBox
-    :param start_date: beginning of time range in ISO8601 format
+    :param start_date: beginning of time range
     :type start_date: str
-    :param end_date: end of time range in ISO8601 format
+    :param end_date: end of time range
     :type end_date: str
     :param absolute_orbit: An absolute orbit number of Sentinel-2 L1C products as defined by ESA
     :type absolute_orbit: int
@@ -153,6 +154,9 @@ def search_iter(tile_id=None, bbox=None, start_date=None, end_date=None, absolut
     if bbox and bbox.crs is not CRS.WGS84:
         bbox = bbox.transform(CRS.WGS84)
 
+    start_date = parse_time(start_date) if start_date else None
+    end_date = parse_time(end_date) if end_date else None
+
     url_params = _prepare_url_params(tile_id, bbox, end_date, start_date, absolute_orbit)
     url_params['maxRecords'] = config.max_opensearch_records_per_query
 
@@ -182,10 +186,10 @@ def _prepare_url_params(tile_id, bbox, end_date, start_date, absolute_orbit):
     :type tile_id: str
     :param bbox: bounding box of requested area in WGS84 CRS
     :type bbox: geometry.BBox
-    :param start_date: beginning of time range in ISO8601 format
-    :type start_date: str
-    :param end_date: end of time range in ISO8601 format
-    :type end_date: str
+    :param start_date: beginning of time range
+    :type start_date: datetime.date
+    :param end_date: end of time range
+    :type end_date: datetime.date
     :param absolute_orbit: An absolute orbit number of Sentinel-2 L1C products as defined by ESA
     :type absolute_orbit: int
     :return: dictionary with parameters as properties when arguments not None
@@ -193,8 +197,8 @@ def _prepare_url_params(tile_id, bbox, end_date, start_date, absolute_orbit):
     """
     url_params = {
         'identifier': tile_id,
-        'startDate': start_date,
-        'completionDate': end_date,
+        'startDate': serialize_time(start_date, use_tz=False) if start_date else None,
+        'completionDate': serialize_time(end_date, use_tz=False) if end_date else None,
         'orbitNumber': absolute_orbit,
         'box': bbox
     }
