@@ -3,30 +3,18 @@ Module implementing an interface with Sentinel Hub Bring your own COG service
 """
 from dataclasses import field, dataclass
 from datetime import datetime
-from typing import Optional, Union
+from typing import Optional
 
 from dataclasses_json import config as dataclass_config
 from dataclasses_json import dataclass_json, LetterCase, Undefined, CatchAll
 
 from .data_collections import DataCollection
-from .config import SHConfig
 from .constants import RequestType, MimeType
-from .download.sentinelhub_client import SentinelHubDownloadClient
 from .geometry import Geometry
-from .sh_utils import SentinelHubFeatureIterator, remove_undefined
-from .time_utils import parse_time, serialize_time
-
-
-datetime_config = dataclass_config(
-    encoder=lambda time: serialize_time(time, use_tz=True) if time else None,
-    decoder=lambda time: parse_time(time, force_datetime=True) if time else None,
-    letter_case=LetterCase.CAMEL
+from .sh_utils import (
+    SentinelHubService, SentinelHubFeatureIterator, BaseCollection, remove_undefined,datetime_config, geometry_config
 )
 
-geometry_config = dataclass_config(encoder=Geometry.get_geojson,
-                                   decoder=lambda x: Geometry.from_geojson(x) if x else None,
-                                   exclude=lambda x: x is None, letter_case=LetterCase.CAMEL)
-
 
 @dataclass_json(letter_case=LetterCase.CAMEL, undefined=Undefined.INCLUDE)
 @dataclass
@@ -39,28 +27,10 @@ class ByocCollectionAdditionalData:
     max_meters_per_pixel_override: Optional[float] = None
 
 
-@dataclass_json(letter_case=LetterCase.CAMEL, undefined=Undefined.INCLUDE)
-@dataclass
-class ByocCollection:
+class ByocCollection(BaseCollection):
     """ Dataclass to hold BYOC collection data
     """
-    name: str
-    s3_bucket: str
-    other_data: CatchAll
-    collection_id: Optional[str] = field(metadata=dataclass_config(field_name='id'), default=None)
-    user_id: Optional[str] = None
-    created: Optional[datetime] = field(metadata=datetime_config, default=None)
     additional_data: Optional[ByocCollectionAdditionalData] = None
-    no_data: Optional[Union[int, float]] = None
-
-    def to_data_collection(self):
-        """ Returns a DataCollection enum for this BYOC collection
-        """
-        if self.additional_data and self.additional_data.bands:
-            band_names = tuple(self.additional_data.bands)
-            return DataCollection.define_byoc(collection_id=self.collection_id, bands=band_names)
-
-        return DataCollection.define_byoc(collection_id=self.collection_id)
 
 
 @dataclass_json(letter_case=LetterCase.CAMEL, undefined=Undefined.INCLUDE)
@@ -79,19 +49,17 @@ class ByocTile:
     additional_data: Optional[dict] = None
 
 
-class SentinelHubBYOC:
+class SentinelHubBYOC(SentinelHubService):
     """ An interface class for Sentinel Hub Bring your own COG (BYOC) API
 
     For more info check `BYOC API reference
     <https://docs.sentinel-hub.com/api/latest/reference/#tag/byoc_collection>`__.
     """
-    def __init__(self, base_url=None, config=None):
-        self.config = config or SHConfig()
-
-        base_url = base_url or self.config.sh_base_url
-        self.byoc_url = f'{base_url.rstrip("/")}/api/v1/byoc'
-
-        self.client = SentinelHubDownloadClient(config=self.config)
+    @staticmethod
+    def _get_service_url(base_url):
+        """ Provides URL to Catalog API
+        """
+        return f'{base_url}/api/v1/byoc'
 
     def iter_collections(self, search=None, **kwargs):
         """ Retrieve collections
@@ -104,7 +72,7 @@ class SentinelHubBYOC:
         """
         return SentinelHubFeatureIterator(
             client=self.client,
-            url=f'{self.byoc_url}/collections',
+            url=f'{self.service_url}/collections',
             params={
                 'search': search,
                 **kwargs
@@ -121,7 +89,7 @@ class SentinelHubBYOC:
         :return: dictionary of the collection
         :rtype: dict
         """
-        url = f'{self.byoc_url}/collections/{self._parse_id(collection)}'
+        url = f'{self.service_url}/collections/{self._parse_id(collection)}'
         return self.client.get_json(url=url, use_session=True)['data']
 
     def create_collection(self, collection):
@@ -134,7 +102,7 @@ class SentinelHubBYOC:
         :rtype: dict
         """
         coll = self._to_dict(collection)
-        url = f'{self.byoc_url}/collections'
+        url = f'{self.service_url}/collections'
         return self.client.get_json(url=url, post_values=coll, use_session=True)['data']
 
     def update_collection(self, collection):
@@ -145,7 +113,7 @@ class SentinelHubBYOC:
         :param collection: ByocCollection object or a dictionary
         """
         coll = self._to_dict(collection)
-        url = f'{self.byoc_url}/collections/{self._parse_id(coll)}'
+        url = f'{self.service_url}/collections/{self._parse_id(coll)}'
         headers = {'Content-Type': MimeType.JSON.get_string()}
         return self.client.get_json(url=url, request_type=RequestType.PUT, post_values=coll,
                                     headers=headers, use_session=True)
@@ -157,7 +125,7 @@ class SentinelHubBYOC:
 
         :param collection: a ByocCollection, dict or collection id string
         """
-        url = f'{self.byoc_url}/collections/{self._parse_id(collection)}'
+        url = f'{self.service_url}/collections/{self._parse_id(collection)}'
         return self.client.get_json(url=url, request_type=RequestType.DELETE, use_session=True)
 
     def copy_tiles(self, from_collection, to_collection):
@@ -168,7 +136,7 @@ class SentinelHubBYOC:
         :param from_collection: a ByocCollection, dict or collection id string
         :param to_collection: a ByocCollection, dict or collection id string
         """
-        url = f'{self.byoc_url}/collections/{self._parse_id(from_collection)}' \
+        url = f'{self.service_url}/collections/{self._parse_id(from_collection)}' \
               f'/copyTiles?toCollection={self._parse_id(to_collection)}'
         return self.client.get_json(url=url, request_type=RequestType.POST, use_session=True)
 
@@ -186,7 +154,7 @@ class SentinelHubBYOC:
         collection_id = self._parse_id(collection)
         return SentinelHubFeatureIterator(
             client=self.client,
-            url=f'{self.byoc_url}/collections/{collection_id}/tiles',
+            url=f'{self.service_url}/collections/{collection_id}/tiles',
             params={
                 'sort': sort,
                 'path': path,
@@ -205,7 +173,7 @@ class SentinelHubBYOC:
         :return: dictionary of the tile
         :rtype: dict
         """
-        url = f'{self.byoc_url}/collections/{self._parse_id(collection)}/tiles/{self._parse_id(tile)}'
+        url = f'{self.service_url}/collections/{self._parse_id(collection)}/tiles/{self._parse_id(tile)}'
         return self.client.get_json(url=url, use_session=True)['data']
 
     def create_tile(self, collection, tile):
@@ -219,7 +187,7 @@ class SentinelHubBYOC:
         :rtype: dict
         """
         _tile = self._to_dict(tile)
-        url = f'{self.byoc_url}/collections/{self._parse_id(collection)}/tiles'
+        url = f'{self.service_url}/collections/{self._parse_id(collection)}/tiles'
         return self.client.get_json(url=url, post_values=_tile, use_session=True)['data']
 
     def update_tile(self, collection, tile):
@@ -231,7 +199,7 @@ class SentinelHubBYOC:
         :param collection: a ByocCollection, dict or collection id string
         :param tile: a ByocTile or dict
         """
-        url = f'{self.byoc_url}/collections/{self._parse_id(collection)}/tiles/{self._parse_id(tile)}'
+        url = f'{self.service_url}/collections/{self._parse_id(collection)}/tiles/{self._parse_id(tile)}'
         headers = {'Content-Type': MimeType.JSON.get_string()}
 
         _tile = self._to_dict(tile)
@@ -253,7 +221,7 @@ class SentinelHubBYOC:
         :param collection: a ByocCollection, dict or collection id string
         :param tile: a ByocTile, dict or tile id string
         """
-        url = f'{self.byoc_url}/collections/{self._parse_id(collection)}/tiles/{self._parse_id(tile)}'
+        url = f'{self.service_url}/collections/{self._parse_id(collection)}/tiles/{self._parse_id(tile)}'
         return self.client.get_json(url=url, request_type=RequestType.DELETE, use_session=True)
 
     @staticmethod
